Standard normal imputation
norm_imputation.RdImputes all missing values by independent draws from a standard normal distribution.
Value
A completed data set with all missing values replaced by draws from a \(N(0,1)\) distribution.
Examples
X <- random_mcar_data(100, 3)
X_imp <- norm_imputation(X)