Energy distance
edistance.RdCalculating energy distance/statistic.
Value
A numeric value giving the energy distance between the original dataset and the imputed dataset.
Details
This function uses the eqdist.e function. According
to this implementation, by default, the function returns the energy statistic
which is given by
$$E(X, Y) = \frac{nm}{n + m} \hat{\varepsilon}{(X, Y)},$$
where \(\hat{\varepsilon}{(X, Y)}\) is the raw energy distance. To
obtain raw energy distance use rescale = TRUE.